# this specfile is inspired from fedoras'one.
# but I choose not to use git sources, I prefer using tarball
%define tarname pep8
%define fname %{tarname}

Name:           python-%{tarname}
Version:        1.7.0
Release:        %mkrel 1
Summary:        Python style guide checker

Group:          Development/Python
# License is held in the comments of pep8.py
# setup.py claims license is Expat license, which is the same as MIT
License:        MIT
URL:            https://github.com/jcrocholl/pep8
Source0:        http://pypi.python.org/packages/source/p/%{fname}/%{fname}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
BuildRequires:  python-sphinx_rtd_theme
Requires:       python-setuptools

%description
pep8 is a tool to check your Python code against some of the style conventions
in PEP 8. It has a plugin architecture, making new checks easy, and its output
is parseable, making it easy to jump to an error location in your editor.

# Python 3 package
%package -n python3-pep8
Summary:    Python style guide checker

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme

%description -n python3-pep8
pep8 is a tool to check your Python code against some of the style
conventions in PEP 8. It has a plugin architecture, making new checks
easy, and its output is parseable, making it easy to jump to an error
location in your editor.

This is a version for Python 3.

%prep
%setup -qn %{tarname}-%{version}
# Remove #! from pep8.py
sed --in-place "s:#!\s*/usr.*::" pep8.py

# Python 3 prep
cp -a . %{py3dir}

%build
%py2_build
%{__python2} setup.py build build_sphinx

# Python 3 build
pushd %{py3dir}
%py3_build
popd

%install
# Python 3 first
pushd %{py3dir}
%py3_install
mv %{buildroot}%{_bindir}/pep8 %{buildroot}%{_bindir}/pep8-%python3_version
popd

# Python 2
%py2_install


%check
%{__python2} pep8.py --testsuite testsuite
%{__python2} pep8.py --doctest

# Python 3 checks
pushd %{py3dir}
PYTHONPATH="%{buildroot}%{python3_sitelib}:$PYTHONPATH" %{__python3} pep8.py --testsuite testsuite
popd

%files
%doc CHANGES.txt README.rst build/sphinx/html/* 
%{_bindir}/pep8
%{python2_sitelib}/%{tarname}.py*
%{python2_sitelib}/%{tarname}-%{version}-*.egg-info

%files -n python3-%{tarname}
%doc CHANGES.txt README.rst build/sphinx/html/*
%{_bindir}/pep8-%python3_version
%{python3_sitelib}/__pycache__/pep8*
%{python3_sitelib}/%{tarname}.py*
%{python3_sitelib}/%{tarname}-%{version}-*.egg-info




%changelog
* Fri May 13 2016 philippem <philippem> 1.7.0-1.mga6
+ Revision: 1014423
- update to 1.7.0

* Fri Feb 19 2016 umeabot <umeabot> 1.6.2-2.mga6
+ Revision: 970728
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 shlomif <shlomif> 1.6.2-1.mga6
+ Revision: 888099
- Add missing BR on sphinx_rtd_theme
- New version + Rebuild for new Python3 3.5.x

* Wed Oct 15 2014 umeabot <umeabot> 1.5.7-4.mga5
+ Revision: 742761
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5.7-3.mga5
+ Revision: 729316
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Wed Sep 03 2014 grenoya <grenoya> 1.5.7-1.mga5
+ Revision: 671527
- new version 1.5.7

* Sat May 31 2014 pterjan <pterjan> 1.5.6-4.mga5
+ Revision: 628878
- Rebuild for new Python

* Fri May 02 2014 grenoya <grenoya> 1.5.6-3.mga5
+ Revision: 619613
- new version 1.5.6

* Tue Oct 22 2013 umeabot <umeabot> 1.4.6-3.mga4
+ Revision: 544024
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.6-2.mga4
+ Revision: 499114
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Oct 01 2013 grenoya <grenoya> 1.4.6-1.mga4
+ Revision: 490010
- new version 1.4.6
- add python3 module
- add check section
- add documentation build

* Fri Jun 07 2013 grenoya <grenoya> 1.4.5-1.mga4
+ Revision: 440277
- new version 1.4.5

* Sun Jan 13 2013 umeabot <umeabot> 1.3.3-2.mga3
+ Revision: 379266
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jul 18 2012 grenoya <grenoya> 1.3.3-1.mga3
+ Revision: 272324
- new version (1.3.3)

* Sun Sep 11 2011 grenoya <grenoya> 0.6.1-1.mga2
+ Revision: 142475
- import package from Fedora
- switch from git version to last tarball version
- clean spec
- imported package python-pep8

